<?php

class composite_views_filter_handler extends views_handler_filter {

	/**
	 * Override query() to do nothing.
	 */
	function query() {}


	/**
	 * Options definition.
	 */
	function option_definition() {
		$options = parent::option_definition();

		$options['composite_views_filter']['contains']['groups'] = array('default' => '');
		$options['composite_views_filter']['contains']['default_group'] = array('default' => '');
		$options['composite_views_filter']['contains']['all_label'] = array('default' => '');
		$options['composite_views_filter']['contains']['classification'] = array('default' => array());

		return $options;
	}


	/**
	 * Define options form.
	 */
	function options_form(&$form, &$form_state) {
		parent::options_form($form, $form_state);

		// No multiple!
		if (isset($form['expose']['multiple'])) {
			$form['expose']['multiple']['#access'] = FALSE;
			$form['expose']['multiple']['#default_value'] = 0;
		}

		$form['composite_views_filter'] = array(
			'#type' => 'fieldset',
			'#title' => t('Groups'),
			'#tree' => TRUE,
			'#collapsed' => FALSE,
			'#collapsible' => FALSE,
		);
		$form['composite_views_filter']['groups'] = array(
			'#type' => 'textarea',
			'#title' => t('Groups'),
			'#default_value' => $this->options['composite_views_filter']['groups'],
			'#required' => TRUE,
			'#description' => t('Define groups like you would options in a List Field: <code>key|Readable label</code>. One per line. Don\'t use the key "always".'),
		);
		$form['composite_views_filter']['default_group'] = array(
			'#type' => 'textfield',
			'#title' => t('Default selected composite filter'),
			'#default_value' => $this->options['composite_views_filter']['default_group'],
			'#description' => t('Leave this empty to disable all composite filters initially.'),
		);
		$form['composite_views_filter']['all_label'] = array(
			'#type' => 'textfield',
			'#title' => t('Label for &quot;- All -&quot;'),
			'#default_value' => $this->options['composite_views_filter']['all_label'],
			'#description' => t('The dropdown label that represents all filter groups. If empty, &quot;- All -&quot; will be used. This string will be translated.'),
		);
	}


	/**
	 * Exposed form.
	 */
	function exposed_form(&$form, &$form_state) {
		parent::exposed_form($form, $form_state);

		$label = $this->options['composite_views_filter']['all_label'] ?: '- All -';

		$form['composite_views_filter']['composite_views_filter_group'] = array(
			'#type' => 'select',
			'#title' => t('Composite Views Filter Group'),
			'#title_display' => 'invisible',
			'#options' => $this->get_groups(),
			'#empty_option' => t($label),
			'#default_value' => $this->options['composite_views_filter']['default_group'],
		);
	}


	/**
	 * Admin summary (in View edit overview).
	 */
	function admin_summary() {
		$groups = $this->get_groups();
		return t('@num groups', array('@num' => count($groups)));
	}


	/**
	 * Helper to parse and return groups.
	 */
	function get_groups() {
		$raw_groups = trim($this->options['composite_views_filter']['groups']);
		if (!$raw_groups) {
			return array();
		}

		$groups = array();
		foreach (explode("\n", $raw_groups) as $raw_group) {
			$group = explode('|', $raw_group, 2);
			isset($group[1]) || $group[1] = $group[0];
			list($key, $label) = $group;
			$groups[$key] = $label;
		}

		return $groups;
	}


	/**
	 * Helper to return saved classification.
	 */
	function get_classification() {
		return $this->options['composite_views_filter']['classification'];
	}

}
